@@ -120,7 +120,7 @@ class script_runner(JobServerPlugin):
     # grab the scripts for this entity.
     query=""
     if sysimage:
-      query="images/" + entityId + "/details"
+      query="systemimages/" + entityId + "/"
     else:
       query="systems/?hostname=" + entityId 
     # print(self.js.mprovURL + query)
@@ -130,7 +130,7 @@ class script_runner(JobServerPlugin):
       entity = response.json()
     except:
       # if this response was bad, try to grab the nads image 
-      query="images/nads/details"
+      query="systemimages/nads/"
       response = self.js.session.get( self.js.mprovURL + query )
       try:
         entity = response.json()
@@ -185,11 +185,14 @@ class script_runner(JobServerPlugin):
     # print(entity['osdistro']['config_params'])
     tmpYamlDict = yaml.safe_load(entity['osdistro']['config_params'])
     if tmpYamlDict is not None:
-      if type(tmpYamlDict) is list:
-        for dict in tmpYamlDict:
-          yaml_merged.update(dict)
-      else: 
-          yaml_merged.update(tmpYamlDict)
+      try:
+        if type(tmpYamlDict) is list:
+          for dict in tmpYamlDict:
+            yaml_merged.update(dict)
+        else: 
+            yaml_merged.update(tmpYamlDict)
+      except:
+        pass
     
     # print(yaml_merged)
     # then the system groups
@@ -197,23 +200,28 @@ class script_runner(JobServerPlugin):
       # print(group['config_params'])
       tmpYamlDict = yaml.safe_load(group['config_params'])
       if tmpYamlDict is not None:
-        if type(tmpYamlDict) is list:
-          for dict in tmpYamlDict:
-            yaml_merged.update(dict)
-        else:
-            yaml_merged.update(tmpYamlDict)
-          
+        try:
+          if type(tmpYamlDict) is list:
+            for dict in tmpYamlDict:
+              yaml_merged.update(dict)
+          else:
+              yaml_merged.update(tmpYamlDict)
+        except:
+          pass  
     # and finally the system/image params
     # print(yaml_merged)
     # print(yaml.safe_load(entity['config_params']))
     tmpYamlDict = yaml.safe_load(entity['config_params'])
     # print(tmpYamlDict)
     if tmpYamlDict is not None:
-      if type(tmpYamlDict) is list:
-        for dict in tmpYamlDict:
-          yaml_merged.update(dict)
-      else: 
-        yaml_merged.update(tmpYamlDict)
+      try:
+        if type(tmpYamlDict) is list:
+          for dict in tmpYamlDict:
+            yaml_merged.update(dict)
+        else: 
+          yaml_merged.update(tmpYamlDict)
+      except:
+        pass
               
     # print(yaml_merged)
     entity['config_params'] = yaml_merged
